/*===========================================================================
 * pv2019.h version 1.0
 * Copyright (C)2000 Micro Technic A-S
 *
 * This file contains #define constants and prototypes for pv2019.c.
 * See pv2019.c.
 */

/* Values for range in PV2019_AIN_Volt() */
#define AIN_1V		0x0000u
#define AIN_2V5		0x1000u
#define AIN_5V		0x2000u
#define AIN_10V		0x3000u

/* Values for avg in PV2019_AIN_Volt() and PV2019_AIN_Curr() */
#define AVG_1		0x0000u
#define AVG_2		0x0001u
#define AVG_4		0x0002u
#define AVG_8		0x0003u
#define AVG_16		0x0004u

/* Values for range in PV2019_AOUT() */
#define AOUT_0_10V	0x6000u
#define AOUT_0_20MA	0x8000u
#define AOUT_4_20MA	0xA000u

/* Return values from PV2019_Init().  Values other than these are the
 * version number of the MPU firmware, meaning that the PV-2019 is OK. */
#define PV2019_ERR_ILLEGAL_BASE	0xFFFFu	/* base not one of the 16 legal ones */
#define PV2019_ERR_NOT_ROOT	0xFFFEu	/* Linux: Program not running as root */
#define PV2019_ERR_NOT_FOUND	0xFFFDu	/* No PV-2019 found at this base address */
#define PV2019_ERR_MPU		0x0000u	/* Timeout communicating with the MPU */


unsigned short PV2019_Cmd           (int base, unsigned short cmd);
unsigned short PV2019_Init          (int base);
int            PV2019_GetInputBit   (int base, int bitno);
unsigned char  PV2019_GetInputByte  (int base);
void           PV2019_SetOutputBit  (int base, int bitno, int value);
int            PV2019_GetOutputBit  (int base, int bitno);
void           PV2019_SetOutputByte (int base, unsigned char value);
unsigned char  PV2019_GetOutputByte (int base);
int            PV2019_AIN_Volt      (int base, int ch, int range, int avg);
int            PV2019_AIN_Curr      (int base, int ch, int avg);
void           PV2019_AOUT          (int base, int ch, int range, int value);
void           PV2019_CntReset      (int base, int cnt);
unsigned char  PV2019_CntStatus     (int base);
unsigned long  PV2019_CntEnable     (int base, int cnt);
unsigned long  PV2019_CntDisable    (int base, int cnt);
